# rocksnot


[![image](https://img.shields.io/pypi/v/rocksnot.svg)](https://pypi.python.org/pypi/rocksnot)
[![image](https://img.shields.io/conda/vn/conda-forge/rocksnot.svg)](https://anaconda.org/conda-forge/rocksnot)


**python package**


-   Free software: MIT license
-   Documentation: https://rlape28.github.io/rocksnot
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
